@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #ifndef SPVM_USE_H
 #define SPVM_USE_H
 
@@ -5,8 +8,8 @@
 
 struct spvm_use {
   SPVM_OP* op_use;
-  const char* class_name;
-  const char* class_alias_name;
+  SPVM_OP* op_type;
+  const char* alias_name;
   const char* file;
   int8_t is_require;
 };
